@@ -18,20 +18,23 @@
 #' @param editable should vector graphics elements (points, text, etc.) be editable.
 #' @param id specifies a unique identifier (integer) within the slide
 #' that will contain the DrawingML instructions.
-#' @param next_rels_id specifies the next unique identifier (integer)
+#' @param last_rel_id specifies the last unique identifier (integer)
 #' within relationship file that will be used to reference embedded
 #' raster images if any.
+#' @param next_rels_id deprecated. Use last_rel_id instead.
 #' @param raster_prefix string value used as prefix for png
 #' files produced when raster objects are printed on the
 #' graphical device.
 #' @param standalone produce a standalone drawingml file? If \code{FALSE}, omits
 #'   xml header and namespaces.
 #' @examples
+#' \donttest{
 #' dml_pptx( file = tempfile() )
 #' plot(1:11,(-5:5)^2, type='b', main="Simple Example")
 #' dev.off()
+#' }
 #' @keywords device
-#' @seealso \code{\link{Devices}}, \code{\link{dml_docx}}, \code{\link{dsvg}}
+#' @seealso \code{\link{Devices}}
 #' @export
 dml_pptx <- function(file = "Rplots.dml", width = 6, height = 6,
                      offx = 1, offy = 1,
@@ -39,7 +42,8 @@ dml_pptx <- function(file = "Rplots.dml", width = 6, height = 6,
                      fonts = list(),
                      pointsize = 12, editable = TRUE,
                      id = 1L,
-                     next_rels_id = 1L,
+                     last_rel_id = 1L,
+                     next_rels_id,
                      raster_prefix = "raster_", standalone = TRUE,
                      fontname_serif = NULL,
                      fontname_sans = NULL,
@@ -61,12 +65,16 @@ dml_pptx <- function(file = "Rplots.dml", width = 6, height = 6,
       fonts$symbol <- fontname_symbol
   }
 
+  if(!missing(next_rels_id)){
+    last_rel_id <- next_rels_id
+  }
+
   system_fonts <- validate_fonts( fonts )
   invisible(PPTX_(file, bg, width, height, offx = offx, offy = offy,
               pointsize = pointsize,
               aliases = list(system = system_fonts, user = list()),
               editable = editable, id = id, raster_prefix = raster_prefix,
-              next_rels_id = next_rels_id, standalone = standalone
+              last_rel_id = last_rel_id, standalone = standalone
             ))
 }
 
